# Generated by roxygen2: do not edit by hand

export(colocboost)
export(colocboost_plot)
export(get_ambiguous_colocalization)
export(get_colocboost_summary)
export(get_cormat)
export(get_cos)
export(get_cos_purity)
export(get_cos_summary)
export(get_hierarchical_clusters)
export(get_robust_colocalization)
export(get_robust_ucos)
export(get_ucos_summary)
importFrom(Rfast,correls)
importFrom(Rfast,med)
importFrom(Rfast,upper_tri)
importFrom(grDevices,adjustcolor)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,legend)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,points)
importFrom(graphics,text)
importFrom(stats,as.dist)
importFrom(stats,cor)
importFrom(stats,cutree)
importFrom(stats,density)
importFrom(stats,dnorm)
importFrom(stats,hclust)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,pchisq)
importFrom(stats,pnorm)
importFrom(stats,predict)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,smooth.spline)
importFrom(stats,var)
importFrom(utils,head)
importFrom(utils,tail)
